@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -25,8 +25,7 @@
 #include <kpimtextedit/richtexteditor.h>
 class KActionCollection;
 
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class RichTextComposerSignatures;
 class RichTextComposerControler;
 class RichTextComposerActions;
@@ -96,7 +95,7 @@ public:
     QString quotePrefixName() const;
 
     void setCursorPositionFromStart(unsigned int pos);
-    int quoteLength(const QString &line) const;
+    int quoteLength(const QString &line, bool oneQuote = false) const;
     bool isLineQuoted(const QString &line) const;
     const QString defaultQuoteSign() const;
     void createActions(KActionCollection *ac);
@@ -107,7 +106,7 @@ public:
     KPIMTextEdit::RichTextComposerControler *composerControler() const;
     KPIMTextEdit::RichTextExternalComposer *externalComposer() const;
     KPIMTextEdit::RichTextComposerActions *composerActions() const;
-    void createHighlighter() Q_DECL_OVERRIDE;
+    void createHighlighter() override;
     virtual bool processAutoCorrection(QKeyEvent *event);
 
 public Q_SLOTS:
@@ -132,13 +131,13 @@ Q_SIGNALS:
     void externalEditorClosed();
 
 protected:
-    void keyPressEvent(QKeyEvent *event) Q_DECL_OVERRIDE;
-    Sonnet::SpellCheckDecorator *createSpellCheckDecorator() Q_DECL_OVERRIDE;
-    void insertFromMimeData(const QMimeData *source) Q_DECL_OVERRIDE;
-    bool canInsertFromMimeData(const QMimeData *source) const Q_DECL_OVERRIDE;
-    void mouseReleaseEvent(QMouseEvent *event) Q_DECL_OVERRIDE;
-    void clearDecorator() Q_DECL_OVERRIDE;
-    void updateHighLighter() Q_DECL_OVERRIDE;
+    void keyPressEvent(QKeyEvent *event) override;
+    Sonnet::SpellCheckDecorator *createSpellCheckDecorator() override;
+    void insertFromMimeData(const QMimeData *source) override;
+    bool canInsertFromMimeData(const QMimeData *source) const override;
+    void mouseReleaseEvent(QMouseEvent *event) override;
+    void clearDecorator() override;
+    void updateHighLighter() override;
     bool processKeyEvent(QKeyEvent *e);
 
 private:
