@@ -35,10 +35,9 @@ class KPIMTextEdit::TextGoToLineWidgetPrivate
 {
 public:
     TextGoToLineWidgetPrivate()
-        : mSpinbox(nullptr),
-          mGoToLine(nullptr)
+        : mSpinbox(nullptr)
+        , mGoToLine(nullptr)
     {
-
     }
 
     QSpinBox *mSpinbox;
@@ -46,8 +45,8 @@ public:
 };
 
 TextGoToLineWidget::TextGoToLineWidget(QWidget *parent)
-    : QWidget(parent),
-      d(new KPIMTextEdit::TextGoToLineWidgetPrivate)
+    : QWidget(parent)
+    , d(new KPIMTextEdit::TextGoToLineWidgetPrivate)
 {
     QHBoxLayout *hbox = new QHBoxLayout(this);
     hbox->setMargin(2);
@@ -132,7 +131,7 @@ bool TextGoToLineWidget::event(QEvent *e)
     // Close the bar when pressing Escape.
     // Not using a QShortcut for this because it could conflict with
     // window-global actions (e.g. Emil Sedgh binds Esc to "close tab").
-    // With a shortcut Q_DECL_OVERRIDE we can catch this before it gets to kactions.
+    // With a shortcut override we can catch this before it gets to kactions.
     const bool shortCutOverride = (e->type() == QEvent::ShortcutOverride);
     if (shortCutOverride || e->type() == QEvent::KeyPress) {
         QKeyEvent *kev = static_cast<QKeyEvent * >(e);
