@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -23,8 +23,7 @@
 #include "kpimtextedit_export.h"
 #include <QWidget>
 
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class TextGoToLineWidgetPrivate;
 class KPIMTEXTEDIT_EXPORT TextGoToLineWidget : public QWidget
 {
@@ -41,8 +40,8 @@ Q_SIGNALS:
     void hideGotoLine();
 
 protected:
-    bool event(QEvent *e) Q_DECL_OVERRIDE;
-    void showEvent(QShowEvent *e) Q_DECL_OVERRIDE;
+    bool event(QEvent *e) override;
+    void showEvent(QShowEvent *e) override;
 
 public Q_SLOTS:
     void slotBlockCountChanged(int numberBlockCount);
@@ -51,7 +50,6 @@ private Q_SLOTS:
     void slotCloseBar();
     void slotGoToLine();
 
-
 private:
     TextGoToLineWidgetPrivate *const d;
 };
