@@ -19,7 +19,7 @@
 
 #include "richtexteditor.h"
 #include "kpimtextedit_debug.h"
-#include "helper_p.h"
+
 #include "texteditor/commonwidget/textmessageindicator.h"
 #include <KLocalizedString>
 #include <KStandardAction>
@@ -53,21 +53,20 @@
 #include <QDialogButtonBox>
 #include <QPushButton>
 
-
 using namespace KPIMTextEdit;
 class Q_DECL_HIDDEN RichTextEditor::RichTextEditorPrivate
 {
 public:
     RichTextEditorPrivate(RichTextEditor *qq)
-        : q(qq),
-          textIndicator(new KPIMTextEdit::TextMessageIndicator(q)),
-          richTextDecorator(nullptr),
-          speller(nullptr),
-          webshortcutMenuManager(new KIO::KUriFilterSearchProviderActions(q)),
-          mInitialFontSize(0),
-          customPalette(false),
-          activateLanguageMenu(true),
-          showAutoCorrectionButton(false)
+        : q(qq)
+        , textIndicator(new KPIMTextEdit::TextMessageIndicator(q))
+        , richTextDecorator(nullptr)
+        , speller(nullptr)
+        , webshortcutMenuManager(new KIO::KUriFilterSearchProviderActions(q))
+        , mInitialFontSize(0)
+        , customPalette(false)
+        , activateLanguageMenu(true)
+        , showAutoCorrectionButton(false)
     {
         KConfig sonnetKConfig(QStringLiteral("sonnetrc"));
         KConfigGroup group(&sonnetKConfig, "Spelling");
@@ -78,6 +77,7 @@ public:
         supportFeatures |= RichTextEditor::AllowTab;
         supportFeatures |= RichTextEditor::AllowWebShortcut;
     }
+
     ~RichTextEditorPrivate()
     {
         delete richTextDecorator;
@@ -102,8 +102,8 @@ public:
 };
 
 RichTextEditor::RichTextEditor(QWidget *parent)
-    : QTextEdit(parent),
-      d(new RichTextEditorPrivate(this))
+    : QTextEdit(parent)
+    , d(new RichTextEditorPrivate(this))
 {
     setAcceptRichText(true);
     KCursor::setAutoHideCursor(this, true, false);
@@ -156,7 +156,9 @@ QMenu *RichTextEditor::mousePopupMenu(QPoint pos)
         const bool emptyDocument = document()->isEmpty();
         if (!isReadOnly()) {
             QList<QAction *> actionList = popup->actions();
-            enum { UndoAct, RedoAct, CutAct, CopyAct, PasteAct, ClearAct, SelectAllAct, NCountActs };
+            enum {
+                UndoAct, RedoAct, CutAct, CopyAct, PasteAct, ClearAct, SelectAllAct, NCountActs
+            };
             QAction *separatorAction = nullptr;
             const int idx = actionList.indexOf(actionList[SelectAllAct]) + 1;
             if (idx < actionList.count()) {
@@ -206,19 +208,18 @@ QMenu *RichTextEditor::mousePopupMenu(QPoint pos)
                 autoSpellCheckAction->setChecked(checkSpellingEnabled());
                 popup->addAction(autoSpellCheckAction);
 
-                if (checkSpellingEnabled() &&  d->activateLanguageMenu) {
+                if (checkSpellingEnabled() && d->activateLanguageMenu) {
                     QMenu *languagesMenu = new QMenu(i18n("Spell Checking Language"), popup);
                     QActionGroup *languagesGroup = new QActionGroup(languagesMenu);
                     languagesGroup->setExclusive(true);
 
-
                     QString defaultSpellcheckingLanguage = spellCheckingLanguage();
                     if (defaultSpellcheckingLanguage.isEmpty()) {
                         defaultSpellcheckingLanguage = d->speller->defaultLanguage();
                     }
 
                     QMapIterator<QString, QString> i(d->speller->availableDictionaries());
-                    while(i.hasNext()) {
+                    while (i.hasNext()) {
                         i.next();
                         QAction *languageAction = languagesMenu->addAction(i.key());
                         languageAction->setCheckable(true);
@@ -241,10 +242,11 @@ QMenu *RichTextEditor::mousePopupMenu(QPoint pos)
         }
 
         if (KPIMTextEdit::TextToSpeech::self()->isReady()) {
-            QAction *speakAction = popup->addAction(i18n("Speak Text"));
-            speakAction->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-text-to-speech")));
-            speakAction->setEnabled(!emptyDocument);
-            connect(speakAction, &QAction::triggered, this, &RichTextEditor::slotSpeakText);
+            if (!emptyDocument) {
+                QAction *speakAction = popup->addAction(i18n("Speak Text"));
+                speakAction->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-text-to-speech")));
+                connect(speakAction, &QAction::triggered, this, &RichTextEditor::slotSpeakText);
+            }
         }
         if (webShortcutSupport() && textCursor().hasSelection()) {
             popup->addSeparator();
@@ -274,13 +276,13 @@ void RichTextEditor::setWebShortcutSupport(bool b)
     if (b) {
         d->supportFeatures |= AllowWebShortcut;
     } else {
-        d->supportFeatures = (d->supportFeatures & ~ AllowWebShortcut);
+        d->supportFeatures = (d->supportFeatures & ~AllowWebShortcut);
     }
 }
 
 bool RichTextEditor::webShortcutSupport() const
 {
-    return (d->supportFeatures & AllowWebShortcut);
+    return d->supportFeatures & AllowWebShortcut;
 }
 
 void RichTextEditor::addIgnoreWords(const QStringList &lst)
@@ -300,13 +302,13 @@ void RichTextEditor::setSearchSupport(bool b)
     if (b) {
         d->supportFeatures |= Search;
     } else {
-        d->supportFeatures = (d->supportFeatures & ~ Search);
+        d->supportFeatures = (d->supportFeatures & ~Search);
     }
 }
 
 bool RichTextEditor::searchSupport() const
 {
-    return (d->supportFeatures & Search);
+    return d->supportFeatures & Search;
 }
 
 void RichTextEditor::setAllowTabSupport(bool b)
@@ -314,13 +316,13 @@ void RichTextEditor::setAllowTabSupport(bool b)
     if (b) {
         d->supportFeatures |= AllowTab;
     } else {
-        d->supportFeatures = (d->supportFeatures & ~ AllowTab);
+        d->supportFeatures = (d->supportFeatures & ~AllowTab);
     }
 }
 
 bool RichTextEditor::allowTabSupport() const
 {
-    return (d->supportFeatures & AllowTab);
+    return d->supportFeatures & AllowTab;
 }
 
 void RichTextEditor::setShowAutoCorrectButton(bool b)
@@ -335,7 +337,7 @@ bool RichTextEditor::showAutoCorrectButton() const
 
 bool RichTextEditor::spellCheckingSupport() const
 {
-    return (d->supportFeatures & SpellChecking);
+    return d->supportFeatures & SpellChecking;
 }
 
 void RichTextEditor::setSpellCheckingSupport(bool check)
@@ -343,7 +345,7 @@ void RichTextEditor::setSpellCheckingSupport(bool check)
     if (check) {
         d->supportFeatures |= SpellChecking;
     } else {
-        d->supportFeatures = (d->supportFeatures & ~ SpellChecking);
+        d->supportFeatures = (d->supportFeatures & ~SpellChecking);
     }
 }
 
@@ -352,13 +354,13 @@ void RichTextEditor::setTextToSpeechSupport(bool b)
     if (b) {
         d->supportFeatures |= TextToSpeech;
     } else {
-        d->supportFeatures = (d->supportFeatures & ~ TextToSpeech);
+        d->supportFeatures = (d->supportFeatures & ~TextToSpeech);
     }
 }
 
 bool RichTextEditor::textToSpeechSupport() const
 {
-    return (d->supportFeatures & TextToSpeech);
+    return d->supportFeatures & TextToSpeech;
 }
 
 void RichTextEditor::slotAllowTab()
@@ -467,7 +469,6 @@ void RichTextEditor::checkSpelling(bool force)
     d->originalDoc = QTextDocumentFragment(document());
     spellDialog->setBuffer(toPlainText());
     spellDialog->show();
-
 }
 
 void RichTextEditor::slotCheckSpelling()
@@ -630,7 +631,6 @@ void RichTextEditor::setCheckSpellingEnabled(bool check)
 
 void RichTextEditor::updateHighLighter()
 {
-
 }
 
 void RichTextEditor::clearDecorator()
@@ -674,6 +674,7 @@ void RichTextEditor::slotLanguageSelected()
     QAction *languageAction = static_cast<QAction *>(QObject::sender());
     setSpellCheckingLanguage(languageAction->data().toString());
 }
+
 static void deleteWord(QTextCursor cursor, QTextCursor::MoveOperation op)
 {
     cursor.clearSelection();
