@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,14 +24,13 @@
 #include "kpimtextedit_export.h"
 #include "texttospeechwidget.h"
 class QAction;
-namespace KPIMTextEdit
-{
+namespace KPIMTextEdit {
 class TextToSpeechActionsPrivate;
 class KPIMTEXTEDIT_EXPORT TextToSpeechActions : public QObject
 {
     Q_OBJECT
 public:
-    explicit TextToSpeechActions(QObject *parent = Q_NULLPTR);
+    explicit TextToSpeechActions(QObject *parent = nullptr);
     ~TextToSpeechActions();
 
     QAction *stopAction() const;
