@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2014-2017 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -32,28 +32,30 @@
 
 using namespace KPIMTextEdit;
 TextToSpeechConfigWidget::TextToSpeechConfigWidget(QWidget *parent)
-    : QWidget(parent),
-      mAbstractTextToSpeechConfigInterface(new TextToSpeechConfigInterface(this))
+    : QWidget(parent)
+    , mAbstractTextToSpeechConfigInterface(new TextToSpeechConfigInterface(this))
 {
-    QFormLayout *layout = new QFormLayout;
-    setLayout(layout);
-    mVolume = new QSlider;
+    QFormLayout *layout = new QFormLayout(this);
+    mVolume = new QSlider(this);
     mVolume->setObjectName(QStringLiteral("volume"));
     mVolume->setRange(0, 100);
     mVolume->setOrientation(Qt::Horizontal);
+    mVolume->setTickPosition(QSlider::TicksBelow);
     connect(mVolume, &QSlider::valueChanged, this, &TextToSpeechConfigWidget::valueChanged);
 
     layout->addRow(i18n("Volume:"), mVolume);
 
-    mRate = new QSlider;
+    mRate = new QSlider(this);
+    mRate->setTickPosition(QSlider::TicksBelow);
     mRate->setObjectName(QStringLiteral("rate"));
     mRate->setRange(-100, 100);
     mRate->setOrientation(Qt::Horizontal);
     layout->addRow(i18n("Rate:"), mRate);
     connect(mRate, &QSlider::valueChanged, this, &TextToSpeechConfigWidget::valueChanged);
 
-    mPitch = new QSlider;
+    mPitch = new QSlider(this);
     mPitch->setRange(-100, 100);
+    mPitch->setTickPosition(QSlider::TicksBelow);
     connect(mPitch, &QSlider::valueChanged, this, &TextToSpeechConfigWidget::valueChanged);
     mPitch->setObjectName(QStringLiteral("pitch"));
     mPitch->setOrientation(Qt::Horizontal);
@@ -65,7 +67,7 @@ TextToSpeechConfigWidget::TextToSpeechConfigWidget(QWidget *parent)
     connect(mAvailableEngine, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &TextToSpeechConfigWidget::slotEngineChanged);
     connect(mAvailableEngine, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &TextToSpeechConfigWidget::valueChanged);
 
-    mLanguage = new KPIMTextEdit::TextToSpeechLanguageComboBox;
+    mLanguage = new KPIMTextEdit::TextToSpeechLanguageComboBox(this);
     mLanguage->setObjectName(QStringLiteral("language"));
     layout->addRow(i18n("Language:"), mLanguage);
     connect(mAvailableEngine, static_cast<void (QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &TextToSpeechConfigWidget::slotLanguageChanged);
@@ -81,7 +83,6 @@ TextToSpeechConfigWidget::TextToSpeechConfigWidget(QWidget *parent)
 
 TextToSpeechConfigWidget::~TextToSpeechConfigWidget()
 {
-
 }
 
 void TextToSpeechConfigWidget::valueChanged()
@@ -106,7 +107,7 @@ void TextToSpeechConfigWidget::readConfig()
     KConfigGroup grp = config.group("Settings");
     mRate->setValue(static_cast<int>(grp.readEntry("rate", 0) * 100));
     mPitch->setValue(static_cast<int>(grp.readEntry("pitch", 0) * 100));
-    mVolume->setValue(static_cast<int>(grp.readEntry("volume", 0)));
+    mVolume->setValue(static_cast<int>(grp.readEntry("volume", 50)));
     updateLocale();
 }
 
@@ -136,11 +137,21 @@ void TextToSpeechConfigWidget::setTextToSpeechConfigInterface(AbstractTextToSpee
     slotUpdateSettings();
 }
 
+void TextToSpeechConfigWidget::restoreDefaults()
+{
+    mRate->setValue(0);
+    mPitch->setValue(0);
+    mVolume->setValue(50);
+
+    //TODO
+}
+
 void TextToSpeechConfigWidget::updateAvailableEngine()
 {
     mAvailableEngine->clear();
     mAvailableEngine->addItem(i18nc("Default tts engine", "Default"), QString());
-    Q_FOREACH (const QString &engine, mAbstractTextToSpeechConfigInterface->availableEngines()) {
+    const QStringList lst = mAbstractTextToSpeechConfigInterface->availableEngines();
+    for (const QString &engine : lst) {
         mAvailableEngine->addItem(engine, engine);
     }
     updateEngine();
@@ -149,7 +160,8 @@ void TextToSpeechConfigWidget::updateAvailableEngine()
 void TextToSpeechConfigWidget::updateAvailableVoices()
 {
     mVoice->clear();
-    Q_FOREACH (const QString &voice, mAbstractTextToSpeechConfigInterface->availableVoices()) {
+    const QStringList lst = mAbstractTextToSpeechConfigInterface->availableVoices();
+    for (const QString &voice : lst) {
         mVoice->addItem(voice, voice);
     }
     updateVoice();
@@ -197,5 +209,4 @@ void TextToSpeechConfigWidget::slotEngineChanged()
 void TextToSpeechConfigWidget::slotLanguageChanged()
 {
     //QLocale locale = mLanguage->currentData().value<QLocale>();
-
 }
